Module: Singly::Services::Service
- Included in:
- Bodymedia, Dropbox, Dwolla, Facebook, Fitbit, Flickr, Foursquare, Gcal, Gcontacts, Gdocs, Github, Gmail, Google, Gplus, Imgur, Instagram, Klout, Linkedin, Meetup, Paypal, Picasa, Rdio, Reddit, Runkeeper, Shutterfly, Soundcloud, Stocktwits, ThirtySevenSignals, Tout, Tumblr, Twitter, Withings, Wordpress, Yammer, Youtube, Zeo
- Defined in:
- lib/singly/api/services/service.rb
Class Method Summary collapse
Instance Method Summary collapse
Class Method Details
Instance Method Details
#service=(service) ⇒ Object
21 22 23 |
# File 'lib/singly/api/services/service.rb', line 21 def service=(service) @service = service end |
#service_endpoint(endpoint_name, params) ⇒ Object
12 13 14 15 16 17 18 19 |
# File 'lib/singly/api/services/service.rb', line 12 def service_endpoint(endpoint_name, params) params ||= {} endpoint_type = params.has_key?(:id) ? Singly::Services::IdEndpoint : Singly::Services::Endpoint endpoint_type.new(creds.merge(params.merge({ service: @service, endpoint: endpoint_name.to_s }))) end |